@@ -1,11 +1,11 @@
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) Xavier Roche and other contributors
+Copyright (C) 1998-2013 Xavier Roche and other contributors
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 3
-of the License, or any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 Important notes:
 
@@ -126,6 +125,29 @@ int cookie_del(t_cookie * cookie, char *cook_name, char *domain, char *path) {
   return 0;
 }
 
+// Matches wildcard cookie domains that start with a dot
+// chk_dom: the domain stored in the cookie (potentially wildcard).
+// domain: query domain
+int cookie_cmp_wildcard_domain(char *chk_dom, char *domain) {
+    int n = strlen(chk_dom);
+    int m = strlen(domain);
+    int l = n < m ? n : m;
+    int i;
+    for (i = l - 1; i >= 0; i--) {
+        if (chk_dom[n - i - 1] != domain[m - i - 1]) {
+            return 1;
+        }
+    }
+    if (m < n && chk_dom[0] == '.') {
+        return 0;
+    }
+    else if (m != n) {
+        return 1;
+    }
+    return 0;
+}
+
+
 // rechercher cookie à partir de la position s (par exemple s=cookie.data)
 // renvoie pointeur sur ligne, ou NULL si introuvable
 // path est aligné à droite et cook_name peut être vide (chercher alors tout cookie)
@@ -145,15 +167,15 @@ char *cookie_find(char *s, char *cook_name, char *domain, char *path) {
       //
       char *chk_dom = cookie_get(buffer, a, 0); // domaine concerné par le cookie
 
-      if ((int) strlen(chk_dom) <= (int) strlen(domain)) {
-        if (strcmp(chk_dom, domain + strlen(domain) - strlen(chk_dom)) == 0) {  // même domaine
+      if (((int) strlen(chk_dom) <= (int) strlen(domain) &&
+        strcmp(chk_dom, domain + strlen(domain) - strlen(chk_dom)) == 0) ||
+        !cookie_cmp_wildcard_domain(chk_dom, domain)) {  // même domaine
           //
-          char *chk_path = cookie_get(buffer, a, 2);    // chemin concerné par le cookie
+        char *chk_path = cookie_get(buffer, a, 2);    // chemin concerné par le cookie
 
-          if ((int) strlen(chk_path) <= (int) strlen(path)) {
-            if (strncmp(path, chk_path, strlen(chk_path)) == 0) {       // même chemin
-              return a;
-            }
+        if ((int) strlen(chk_path) <= (int) strlen(path)) {
+          if (strncmp(path, chk_path, strlen(chk_path)) == 0) {       // même chemin
+            return a;
           }
         }
       }
