@@ -1,12 +1,12 @@
 /* ------------------------------------------------------------ */
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) Xavier Roche and other contributors
+Copyright (C) 1998-2013 Xavier Roche and other contributors
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 3
-of the License, or any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 Important notes:
 
@@ -198,11 +197,12 @@ HTSEXT_API int catch_url(T_SOC soc, char *url, char *method, char *data) {
           char BIGSTK url_fil[HTS_URLMAXSIZE * 2];
 
           // méthode en majuscule
-          int i, r = 0;
+          size_t i;
+          int r = 0;
 
           url_adr[0] = url_fil[0] = '\0';
           //
-          for(i = 0; i < (int) strlen(method); i++) {
+          for(i = 0; method[i] != '\0'; i++) {
             if ((method[i] >= 'a') && (method[i] <= 'z'))
               method[i] -= ('a' - 'A');
           }
