@@ -1,12 +1,12 @@
 /* ------------------------------------------------------------ */
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) Xavier Roche and other contributors
+Copyright (C) 1998-2013 Xavier Roche and other contributors
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 3
-of the License, or any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 Important notes:
 
@@ -485,7 +484,7 @@ static int tris(httrackp * opt, char *buffer) {
 static char *printname(char rname[1024], char name[1024]) {
   char *p;
   char *p1;
-  int j;
+  size_t j;
 
   rname[0] = '\0';
   //
@@ -497,7 +496,7 @@ static char *printname(char rname[1024], char name[1024]) {
   p += 2;
   //rname=(char*)calloct(strlen(name)+8,sizeof(char));
   p1 = rname;
-  for(j = 0; j < (int) strlen(name); j++, p++) {
+  for(j = 0; name[j] != '\0'; j++, p++) {
     if (*p == '/')
       *p1 = '.';
     if (*p == ';') {
