@@ -1,12 +1,12 @@
 /* ------------------------------------------------------------ */
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) Xavier Roche and other contributors
+Copyright (C) 1998-2013 Xavier Roche and other contributors
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 3
-of the License, or any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 Important notes:
 
@@ -216,19 +215,17 @@ struct OLD_htsblk {
 typedef struct t_dnscache t_dnscache;
 #endif
 struct t_dnscache {
-  char iadr[1024];
   struct t_dnscache *n;
-  char host_addr[HTS_MAXADDRLEN];       // 4 octets (v4), ou 16 octets (v6)
   int host_length;              // 4 normalement - ==0  alors en cours de résolution
+  char host_addr[HTS_MAXADDRLEN];       // 4 octets (v4), ou 16 octets (v6)
   // ou >16 si sockaddr
   //                 ==-1 alors erreur (host n'éxiste pas)
+  char iadr[1024];
 };
 
 /* Library internal definictions */
 #ifdef HTS_INTERNAL_BYTECODE
 
-extern htsmutex dns_lock;
-
 // initialize an htsblk structure
 void hts_init_htsblk(htsblk * r);
 
@@ -298,12 +295,11 @@ HTS_INLINE t_hostent *hts_gethostbyname(httrackp * opt, const char *iadr,
 HTSEXT_API t_hostent *vxgethostbyname2(char *hostname, void *v_buffer, const char **error);
 HTSEXT_API t_hostent *vxgethostbyname(char *hostname, void *v_buffer);
 #endif
-t_hostent *_hts_ghbn(t_dnscache * cache, const char *iadr, t_hostent * retour);
 int ftp_available(void);
 
 #if HTS_DNSCACHE
 void hts_cache_free(t_dnscache * cache);
-int hts_dnstest(httrackp * opt, const char *_iadr);
+int hts_dnstest(httrackp * opt, const char *_iadr, int add);
 t_dnscache *_hts_cache(httrackp * opt);
 #endif
 
