@@ -1,12 +1,12 @@
 /* ------------------------------------------------------------ */
 /*
 HTTrack Website Copier, Offline Browser for Windows and Unix
-Copyright (C) Xavier Roche and other contributors
+Copyright (C) 1998-2013 Xavier Roche and other contributors
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 3
-of the License, or any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 Important notes:
 
@@ -444,7 +443,23 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
           // note: if savename_delayed is enabled, the naming will be temporary (and slightly invalid!)
           // note: if we are about to stop (opt->state.stop), back_add() will fail later
           else if (opt->savename_delayed != 0 && !opt->state.stop) {
-            if (mime_type != NULL) {
+            // Check if the file is ready in backing. We basically take the same logic as later.
+            // FIXME: we should cleanup and factorize this unholy mess
+            if (headers != NULL && headers->status >= 0) {
+              if (strnotempty(headers->r.cdispo)) {        /* filename given */
+                ext_chg = 2;      /* change filename */
+                strcpybuff(ext, headers->r.cdispo);
+              } else if (!may_unknown2(opt, headers->r.contenttype, headers->url_fil)) {    // on peut patcher à priori? (pas interdit ou pas de type)
+                char s[16];
+                s[0] = '\0';
+                give_mimext(s, headers->r.contenttype);    // obtenir extension
+                if (strnotempty(s) > 0) { // on a reconnu l'extension
+                  ext_chg = 1;
+                  strcpybuff(ext, s);
+                }
+              }
+            }
+            else if (mime_type != NULL) {
               ext[0] = '\0';
               if (*mime_type) {
                 give_mimext(ext, mime_type);
@@ -1181,7 +1196,7 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
       }
       break;
     case 99:{                  // 'codé' .. c'est un gadget
-        int i;
+        size_t i;
         int j;
         char *a;
         char C[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-";
@@ -1191,10 +1206,10 @@ int url_savename(char *adr_complete, char *fil_complete, char *save,
         unsigned int s = 0;
 
         L = (int) strlen(C);
-        for(i = 0; i < (int) strlen(fil_complete); i++) {
+        for(i = 0; fil_complete[i] != '\0'; i++) {
           s += (unsigned int) fil_complete[i];
         }
-        for(i = 0; i < (int) strlen(adr_complete); i++) {
+        for(i = 0; adr_complete[i] != '\0'; i++) {
           s += (unsigned int) adr_complete[i];
         }
         srand(s);
